currentEmbeddingFingerprint property

String get currentEmbeddingFingerprint

Fingerprint computed from the currently loaded embedding model ({modelBasename}|{dim}|{quant}). Stable across reboots as long as the host app keeps loading the same model file.

Implementation

String get currentEmbeddingFingerprint =>
    _engine!.currentEmbeddingFingerprint;