reembedRemaining method
Up-to-date count of chunks still tagged with a non-current fingerprint. Safe to call while reembedAll is running.
Implementation
Future<int> reembedRemaining() => _engine!.reembedRemaining();
Up-to-date count of chunks still tagged with a non-current fingerprint. Safe to call while reembedAll is running.
Future<int> reembedRemaining() => _engine!.reembedRemaining();