RagError class sealed

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

RagError.databaseError(String field0)
Database related error (potential for retry).
const
factory
RagError.internalError(String field0)
Internal system error (HNSW, Logic, etc.).
const
factory
RagError.invalidInput(String field0)
User input error (invalid query, etc.).
const
factory
RagError.ioError(String field0)
I/O error (file missing, permission issues, etc.).
const
factory
RagError.modelLoadError(String field0)
Failed to load embedding model.
const
factory
RagError.unknown(String field0)
Unknown error.
const
factory

Properties

copyWith → $RagErrorCopyWith<RagError>
Create a copy of RagError with the given fields replaced by the non-null parameter values.
no setterinherited
field0 String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message String

Available on RagError, provided by the RagErrorMessage extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
technicalMessage String

Available on RagError, provided by the RagErrorUi extension

The technical details for debugging (same as original message).
no setter
userFriendlyMessage String

Available on RagError, provided by the RagErrorUi extension

A user-friendly message suitable for UI display (Snackbars, Dialogs).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited