SearchHandle class abstract

Constructors

SearchHandle()

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether the underlying Arc is disposed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assembleContext({required AssembleContextOptions options}) Future<AssembledContextV2>
dispose() Future<void>
Dispose the underlying Arc.
getChunkExcerpts({required Int64List chunkIds, required int maxBytes}) Future<List<ChunkExcerptResult>>
hitMeta() Future<List<SearchHitMeta>>
hydrateChunks({required Int64List chunkIds}) Future<List<ChunkSearchResult>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited