SearchHitMeta class

Constructors

SearchHitMeta({required PlatformInt64 chunkId, required PlatformInt64 sourceId, required int chunkIndex, required double similarity, required String rawType, String? headerPathPreview})
const

Properties

chunkId → PlatformInt64
final
chunkIndex int
final
hashCode int
The hash code for this object.
no setteroverride
headerPathPreview String?
final
rawType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
similarity double
final
sourceId → PlatformInt64
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override