SemanticChunk class

Semantic chunk result.

Constructors

SemanticChunk({required int index, required String content, required int startPos, required int endPos, required String chunkType})
const

Properties

chunkType String
final
content String
final
endPos int
final
hashCode int
The hash code for this object.
no setteroverride
index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startPos int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override