SourceEntry class

Constructors

SourceEntry({required PlatformInt64 id, String? name, required PlatformInt64 createdAt, String? metadata, String? status, required String collectionId})
const

Properties

collectionId String
final
createdAt → PlatformInt64
final
hashCode int
The hash code for this object.
no setteroverride
id → PlatformInt64
final
metadata String?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override