extractTextFromFile function
Read a file and extract text according to extension / magic bytes.
Text-like files (.txt, .md, .markdown) are decoded as UTF-8.
Binary document types fall back to the existing document extractor.
Implementation
Future<String> extractTextFromFile({required String filePath}) => RustLib
.instance
.api
.crateApiDocumentParserExtractTextFromFile(filePath: filePath);