RagModelPack class
A reference to a model-pack manifest bundled as a Flutter asset.
Constructors
- RagModelPack.asset(String manifestAsset)
-
Creates a model-pack reference for
manifestAsset.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- manifestAsset → String
-
Asset path of the JSON manifest.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited