RagModelPackErrorCode enum

Error categories emitted while parsing, installing, or resolving a pack.

Inheritance
Available extensions

Values

invalidManifest → const RagModelPackErrorCode
unsupportedSchema → const RagModelPackErrorCode
unsupportedPreset → const RagModelPackErrorCode
invalidRevision → const RagModelPackErrorCode
invalidAssetPath → const RagModelPackErrorCode
invalidHash → const RagModelPackErrorCode
invalidLength → const RagModelPackErrorCode
unsupportedArchitecture → const RagModelPackErrorCode
unsupportedVectorStorage → const RagModelPackErrorCode
assetMissing → const RagModelPackErrorCode
assetLengthMismatch → const RagModelPackErrorCode
assetHashMismatch → const RagModelPackErrorCode
outputOutsideProject → const RagModelPackErrorCode
existingFileMismatch → const RagModelPackErrorCode
downloadFailed → const RagModelPackErrorCode
embeddingDimensionMismatch → const RagModelPackErrorCode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RagModelPackErrorCode>
A constant List of the values in this enum, in order of their declaration.