RagModelPackException class

A typed failure in the Model Pack v1 contract.

Implemented types

Constructors

RagModelPackException(RagModelPackErrorCode code, String message)
const

Properties

code RagModelPackErrorCode
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited