IngestLatencyStats class

Constructors

IngestLatencyStats({required double p50Ms, required double p95Ms, required double meanMs, required double stdevMs, required List<double> samples})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
meanMs double
final
p50Ms double
final
p95Ms double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samples List<double>
final
stdevMs double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited