metaBytes property
Metadata-style strings surfaced to Dart, such as chunk type, header preview, or source metadata.
Implementation
final int metaBytes;
Metadata-style strings surfaced to Dart, such as chunk type, header preview, or source metadata.
final int metaBytes;