PromptBudgetOptions class

Constructors

PromptBudgetOptions({int safetyMarginTokens = 0, int? fixedPromptOverheadTokens, TokenCounter? targetPromptTokenCounter})
const

Properties

fixedPromptOverheadTokens int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetyMarginTokens int
final
targetPromptTokenCounter TokenCounter?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited