expectedEmbeddingDimension property
Expected output dimension of a verified model pack, if one was used.
Implementation
final int? expectedEmbeddingDimension;
Expected output dimension of a verified model pack, if one was used.
final int? expectedEmbeddingDimension;