SearchHydrationMode enum

Hydration mode for high-level hybrid search results.

Inheritance
Available extensions

Values

full → const SearchHydrationMode

Preserve the legacy full-content chunk contract.

preview → const SearchHydrationMode

Return lightweight excerpt-based chunks for UI/debug style listing.

contextOnly → const SearchHydrationMode

Return only assembled context and omit chunk payloads.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SearchHydrationMode>
A constant List of the values in this enum, in order of their declaration.