SearchMetaResult class

Result of the additive low-level search lane.

hits is a bounded metadata-only view. Use handle for explicit hydration or Rust-side context assembly when needed.

Constructors

SearchMetaResult({required SearchHandle handle, required List<SearchHitMeta> hits})
const

Properties

handle SearchHandle
final
hashCode int
The hash code for this object.
no setterinherited
hits List<SearchHitMeta>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited