SourceAddResult class

Result of adding a source document with automatic chunking.

Constructors

SourceAddResult({required int sourceId, required bool isDuplicate, required int chunkCount, required String message, int? bodyByteLength, int? bodyCharLength})

Properties

bodyByteLength int?
UTF-8 byte length of the text body after file parsing / decoding.
final
bodyCharLength int?
Text length as Dart String.length would report it (UTF-16 code units).
final
chunkCount int
final
hashCode int
The hash code for this object.
no setterinherited
isDuplicate bool
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited