RagModelPackManifest class
Schema v1 metadata for one immutable, bundled model pack.
Model Pack v1 always uses Q8_0 vector storage. It deliberately has no VABQ profile field: a manifest cannot silently opt into VABQ.
Constructors
- RagModelPackManifest({required int schemaVersion, required String preset, required String modelId, required String revision, required String modelAsset, required String tokenizerAsset, required String modelSha256, required String tokenizerSha256, required int modelBytes, required int tokenizerBytes, required String architecture, required int embeddingDimension, required String license, required String language, String? declaredVectorStorage})
-
const
-
RagModelPackManifest.fromJson(Map<
String, dynamic> json) -
factory
- RagModelPackManifest.fromJsonString(String source)
-
factory
Properties
- architecture → String
-
final
- embeddingDimension → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String
-
final
- license → String
-
final
- modelAsset → String
-
final
- modelBytes → int
-
final
- modelId → String
-
final
- modelSha256 → String
-
final
- preset → String
-
final
- revision → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
final
- tokenizerAsset → String
-
final
- tokenizerBytes → int
-
final
- tokenizerSha256 → String
-
final
- vectorStorage → String
-
Model Pack v1 is intentionally fixed to Q8_0.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object> -
toJsonString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
validateEmbeddingDimension(
int actualDimension) → void - Rejects a loaded ONNX model whose actual output does not match this pack.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
validateExpectedEmbeddingDimension(
{required int expectedDimension, required int actualDimension}) → void
Constants
- q8_0 → const String
- supportedSchemaVersion → const int