DetailedBenchmarkStats class
Detailed benchmark statistics for reproducible validation.
Constructors
Properties
- avgMs → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxMs → double
-
final
- measuredIterations → int
-
final
- minMs → double
-
final
- p50Ms → double
-
final
- p95Ms → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
samplesMs
→ List<
double> -
final
- stdDevMs → double
-
final
- warmupIterations → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited